#[repr(C)]pub struct WlanPhyImplGetTxPowerScenarioResponse {
pub scenario: TxPowerScenario,
}Expand description
The wire type corresponding to WlanPhyImplGetTxPowerScenarioResponse.
Fields
scenario: TxPowerScenarioTrait Implementations
Sourceimpl Clone for WlanPhyImplGetTxPowerScenarioResponse
impl Clone for WlanPhyImplGetTxPowerScenarioResponse
Sourcefn clone(&self) -> WlanPhyImplGetTxPowerScenarioResponse
fn clone(&self) -> WlanPhyImplGetTxPowerScenarioResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for WlanPhyImplGetTxPowerScenarioResponse
impl Constrained for WlanPhyImplGetTxPowerScenarioResponse
Sourceimpl<___D> Decode<___D> for WlanPhyImplGetTxPowerScenarioResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for WlanPhyImplGetTxPowerScenarioResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<WlanPhyImplGetTxPowerScenarioResponse, ___E> for &'a WlanPhyImplGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanPhyImplGetTxPowerScenarioResponse, ___E> for &'a WlanPhyImplGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyImplGetTxPowerScenarioResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyImplGetTxPowerScenarioResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<WlanPhyImplGetTxPowerScenarioResponse, ___E> for WlanPhyImplGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanPhyImplGetTxPowerScenarioResponse, ___E> for WlanPhyImplGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, WlanPhyImplGetTxPowerScenarioResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, WlanPhyImplGetTxPowerScenarioResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyImplGetTxPowerScenarioResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyImplGetTxPowerScenarioResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<WlanPhyImplGetTxPowerScenarioResponse, ___E> for WlanPhyImplGetTxPowerScenarioResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<TxPowerScenario, ___E>,
impl<___E, T0> Encode<WlanPhyImplGetTxPowerScenarioResponse, ___E> for WlanPhyImplGetTxPowerScenarioResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<TxPowerScenario, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyImplGetTxPowerScenarioResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyImplGetTxPowerScenarioResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<WlanPhyImplGetTxPowerScenarioResponse> for WlanPhyImplGetTxPowerScenarioResponse
impl FromWire<WlanPhyImplGetTxPowerScenarioResponse> for WlanPhyImplGetTxPowerScenarioResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WlanPhyImplGetTxPowerScenarioResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<WlanPhyImplGetTxPowerScenarioResponse, Self>
Sourcefn from_wire(wire: WlanPhyImplGetTxPowerScenarioResponse) -> Self
fn from_wire(wire: WlanPhyImplGetTxPowerScenarioResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<WlanPhyImplGetTxPowerScenarioResponse> for WlanPhyImplGetTxPowerScenarioResponse
impl FromWireRef<WlanPhyImplGetTxPowerScenarioResponse> for WlanPhyImplGetTxPowerScenarioResponse
Sourcefn from_wire_ref(wire: &WlanPhyImplGetTxPowerScenarioResponse) -> Self
fn from_wire_ref(wire: &WlanPhyImplGetTxPowerScenarioResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for WlanPhyImplGetTxPowerScenarioResponse
impl IntoNatural for WlanPhyImplGetTxPowerScenarioResponse
Sourcetype Natural = WlanPhyImplGetTxPowerScenarioResponse
type Natural = WlanPhyImplGetTxPowerScenarioResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for WlanPhyImplGetTxPowerScenarioResponse
impl Wire for WlanPhyImplGetTxPowerScenarioResponse
Sourcetype Narrowed<'de> = WlanPhyImplGetTxPowerScenarioResponse
type Narrowed<'de> = WlanPhyImplGetTxPowerScenarioResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.